@@ -3,7 +3,7 @@
 # we need a minimum of automake 1.6 and automake 1.8 seems to be buggy
 export WANT_AUTOMAKE=1.6
 
-aclocal-1.7 -I mk/autoconf
+aclocal -I mk/autoconf
 automake --copy --add-missing
 autoconf
 
