@@ -1,4 +1,4 @@
-//  $Id: badguy.cpp,v 1.68.2.2 2004/08/03 18:47:15 rmcruz Exp $
+//  $Id: badguy.cpp 2620 2005-06-18 12:12:10Z matzebraun $
 // 
 //  SuperTux
 //  Copyright (C) 2000 Bill Kendrick <bill@newbreedsoftware.com>
@@ -804,17 +804,10 @@ BadGuy::bump()
   kill_me(25);
 }
 
-void
-BadGuy::make_player_jump(Player* player)
-{
-  player->physic.set_velocity_y(2);
-  player->base.y = base.y - player->base.height - 2;
-}
-
 void
 BadGuy::squish_me(Player* player)
 {
-  make_player_jump(player);
+  player->jump_of_badguy(this);
     
   World::current()->add_score(base.x - scroll_x,
                               base.y, 50 * player_status.score_multiplier);
@@ -834,8 +827,8 @@ BadGuy::squish(Player* player)
   if(kind == BAD_MRBOMB) {
     // mrbomb transforms into a bomb now
     World::current()->add_bad_guy(base.x, base.y, BAD_BOMB);
-    
-    make_player_jump(player);
+   
+    player->jump_of_badguy(this);
     World::current()->add_score(base.x - scroll_x, base.y, 50 * player_status.score_multiplier);
     play_sound(sounds[SND_SQUISH], SOUND_CENTER_SPEAKER);
     player_status.score_multiplier++;
@@ -869,7 +862,7 @@ BadGuy::squish(Player* player)
         set_sprite(img_mriceblock_flat_left, img_mriceblock_flat_right);
       }
 
-    make_player_jump(player);
+    player->jump_of_badguy(this);
 
     player_status.score_multiplier++;
 
@@ -885,8 +878,8 @@ BadGuy::squish(Player* player)
     // fish can only be killed when falling down
     if(physic.get_velocity_y() >= 0)
       return;
-      
-    make_player_jump(player);
+    
+    player->jump_of_badguy(this);
 	      
     World::current()->add_score(base.x - scroll_x, base.y, 25 * player_status.score_multiplier);
     player_status.score_multiplier++;
